<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BackThread</name>
    <message>
        <source>Confirm your Wi-Fi password</source>
        <translation type="vanished">请再次确认Wi-Fi密码</translation>
    </message>
</context>
<context>
    <name>ConfForm</name>
    <message>
        <location filename="../src/confform.cpp" line="39"/>
        <source>edit network</source>
        <translation>编辑网络设置</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="106"/>
        <source>LAN name: </source>
        <translation type="unfinished">网络名称：</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="107"/>
        <source>Method: </source>
        <translation>编辑IP设置: </translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="108"/>
        <source>Address: </source>
        <translation>IP地址: </translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="109"/>
        <source>Netmask: </source>
        <translation>子网掩码: </translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="110"/>
        <source>Gateway: </source>
        <translation>默认网关: </translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="111"/>
        <source>DNS 1: </source>
        <translation>首选DNS: </translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="112"/>
        <source>DNS 2: </source>
        <translation>备选DNS: </translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="114"/>
        <source>Edit Conn</source>
        <translation>网络设置</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="115"/>
        <source>Auto(DHCP)</source>
        <translation>自动(DHCP)</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="116"/>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="126"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="127"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="128"/>
        <source>Ok</source>
        <translation type="unfinished">确定</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="220"/>
        <source>Can not create new wired network for without wired card</source>
        <translation type="unfinished">缺少有线网卡 无法新建网络</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="236"/>
        <source>New network already created</source>
        <translation type="unfinished">已创建新的有线网络</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="276"/>
        <source>New network settings already finished</source>
        <translation type="unfinished">新的网络配置已经完成</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="309"/>
        <source>Edit Network</source>
        <translation type="unfinished">编辑网络设置</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="344"/>
        <source>Add Wired Network</source>
        <translation type="unfinished">新建有线网络</translation>
    </message>
    <message>
        <source>create wired network successfully</source>
        <translation type="obsolete">已创建新的有线网络</translation>
    </message>
    <message>
        <source>change configuration of wired network successfully</source>
        <translation type="obsolete">新的设置已经生效</translation>
    </message>
    <message>
        <location filename="../src/confform.cpp" line="285"/>
        <source>New settings already effective</source>
        <translation>新的设置已经生效</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifi</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="77"/>
        <source>Add Hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="78"/>
        <source>Connection</source>
        <translation>连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="79"/>
        <source>Wi-Fi name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="80"/>
        <source>Wi-Fi security</source>
        <translation>Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="81"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="82"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="84"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="105"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.cpp" line="106"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation>WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="vanished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="vanished">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="vanished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="vanished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifi.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiLeap</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="68"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="69"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="70"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="71"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="72"/>
        <source>Username</source>
        <translation>用户名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="73"/>
        <source>Password</source>
        <translation>密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="74"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="75"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="77"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="95"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="96"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="97"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="98"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="100"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifileap.cpp" line="101"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecFast</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="83"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="84"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="85"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="86"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="87"/>
        <source>Authentication</source>
        <translation>认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="88"/>
        <source>Anonymous identity</source>
        <translation>匿名身份:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="89"/>
        <source>Allow automatic PAC pro_visioning</source>
        <translation>自动PAC配置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="90"/>
        <source>PAC file</source>
        <translation>PAC文件:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="91"/>
        <source>Inner authentication</source>
        <translation>内部认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="92"/>
        <source>Username</source>
        <translation type="unfinished">用户名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="93"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="94"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="95"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="100"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="118"/>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="148"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="119"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="120"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="121"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="123"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="124"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="136"/>
        <source>Tunneled TLS</source>
        <translation>隧道 TLS</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="137"/>
        <source>Protected EAP (PEAP)</source>
        <translation>受保护的 EAP</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="143"/>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="144"/>
        <source>Authenticated</source>
        <translation>已认证</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecfast.cpp" line="145"/>
        <source>Both</source>
        <translation>两者兼用</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecLeap</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="73"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="74"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="75"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="76"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="77"/>
        <source>Authentication</source>
        <translation type="unfinished">认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="78"/>
        <source>Username</source>
        <translation type="unfinished">用户名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="79"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="80"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="81"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="83"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="101"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="102"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="103"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="104"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="106"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="107"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="119"/>
        <source>Tunneled TLS</source>
        <translation type="unfinished">隧道 TLS</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecleap.cpp" line="120"/>
        <source>Protected EAP (PEAP)</source>
        <translation type="unfinished">受保护的 EAP</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecPeap</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="91"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="92"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="93"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="94"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="95"/>
        <source>Authentication</source>
        <translation type="unfinished">认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="96"/>
        <source>Anonymous identity</source>
        <translation type="unfinished">匿名身份:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="97"/>
        <source>Domain</source>
        <translation>域名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="98"/>
        <source>CA certificate</source>
        <translation>CA 证书:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="99"/>
        <source>CA certificate password</source>
        <translation>CA 证书密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="100"/>
        <source>No CA certificate is required</source>
        <translation>不需要CA证书</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="101"/>
        <source>PEAP version</source>
        <translation>PEAP版本:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="102"/>
        <source>Inner authentication</source>
        <translation type="unfinished">内部认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="103"/>
        <source>Username</source>
        <translation type="unfinished">用户名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="104"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="105"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="106"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="126"/>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="149"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="127"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="128"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="129"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="131"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="132"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="144"/>
        <source>Tunneled TLS</source>
        <translation type="unfinished">隧道 TLS</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="145"/>
        <source>Protected EAP (PEAP)</source>
        <translation type="unfinished">受保护的 EAP</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="150"/>
        <source>Choose from file</source>
        <translation>从文件选择...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="153"/>
        <source>Automatic</source>
        <translation>自动</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="154"/>
        <source>Version 0</source>
        <translation>版本 0</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpeap.cpp" line="155"/>
        <source>Version 1</source>
        <translation>版本 1</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecPwd</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="74"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="75"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="76"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="77"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="78"/>
        <source>Authentication</source>
        <translation type="unfinished">认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="79"/>
        <source>Username</source>
        <translation type="unfinished">用户名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="80"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="81"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="82"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="84"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="102"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="103"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="104"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="105"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="107"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="108"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="120"/>
        <source>Tunneled TLS</source>
        <translation type="unfinished">隧道 TLS</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisecpwd.cpp" line="121"/>
        <source>Protected EAP (PEAP)</source>
        <translation type="unfinished">受保护的 EAP</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecTls</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="90"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="91"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="92"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="93"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="94"/>
        <source>Authentication</source>
        <translation type="unfinished">认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="95"/>
        <source>Identity</source>
        <translation>身份:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="96"/>
        <source>Domain</source>
        <translation type="unfinished">域名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="97"/>
        <source>CA certificate</source>
        <translation type="unfinished">CA 证书:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="98"/>
        <source>CA certificate password</source>
        <translation type="unfinished">CA 证书密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="99"/>
        <source>No CA certificate is required</source>
        <translation>不需要CA证书</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="100"/>
        <source>User certificate</source>
        <translation>用户证书:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="101"/>
        <source>User certificate password</source>
        <translation>用户证书密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="102"/>
        <source>User private key</source>
        <translation>用户私钥:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="103"/>
        <source>User key password</source>
        <translation>用户密钥密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="104"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="105"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="107"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="125"/>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="148"/>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="152"/>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="156"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="126"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="127"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="128"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="130"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="131"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="143"/>
        <source>Tunneled TLS</source>
        <translation type="unfinished">隧道 TLS</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="144"/>
        <source>Protected EAP (PEAP)</source>
        <translation type="unfinished">受保护的 EAP</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="149"/>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="153"/>
        <location filename="../wireless-security/dlgconnhidwifisectls.cpp" line="157"/>
        <source>Choose from file</source>
        <translation type="unfinished">从文件选择...</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiSecTunnelTLS</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="89"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="90"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="91"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="92"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="93"/>
        <source>Authentication</source>
        <translation type="unfinished">认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="94"/>
        <source>Anonymous identity</source>
        <translation type="unfinished">匿名身份:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="95"/>
        <source>Domain</source>
        <translation type="unfinished">域名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="96"/>
        <source>CA certificate</source>
        <translation type="unfinished">CA 证书:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="97"/>
        <source>CA certificate password</source>
        <translation type="unfinished">CA 证书密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="98"/>
        <source>No CA certificate is required</source>
        <translation>不需要CA证书</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="99"/>
        <source>Inner authentication</source>
        <translation type="unfinished">内部认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="100"/>
        <source>Username</source>
        <translation type="unfinished">用户名:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="101"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="102"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="103"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="105"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="123"/>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="146"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="124"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="125"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="126"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="128"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="129"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="141"/>
        <source>Tunneled TLS</source>
        <translation type="unfinished">隧道 TLS</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="142"/>
        <source>Protected EAP (PEAP)</source>
        <translation type="unfinished">受保护的 EAP</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifisectunneltls.cpp" line="147"/>
        <source>Choose from file</source>
        <translation type="unfinished">从文件选择...</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiWep</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="73"/>
        <source>Add hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="74"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="75"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="76"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="77"/>
        <source>Key</source>
        <translation>密钥</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="78"/>
        <source>WEP index</source>
        <translation>WEP 检索</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="79"/>
        <source>Authentication</source>
        <translation type="unfinished">认证:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="80"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="81"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="83"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="101"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="102"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="103"/>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="unfinished">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="104"/>
        <source>WEP 128-bit Passphrase</source>
        <translation type="unfinished">WEP 128 位密码句</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="106"/>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="unfinished">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="107"/>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="unfinished">WPA 及 WPA2 企业</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="115"/>
        <source>1(default)</source>
        <translation>1(默认)</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="121"/>
        <source>Open System</source>
        <translation>开放式系统</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwep.cpp" line="122"/>
        <source>Shared Key</source>
        <translation>共享密钥</translation>
    </message>
</context>
<context>
    <name>DlgConnHidWifiWpa</name>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.ui" line="14"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="82"/>
        <source>Add Hidden Wi-Fi</source>
        <translation type="unfinished">加入隐藏Wi-Fi</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="83"/>
        <source>Connection</source>
        <translation type="unfinished">连接设置:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="84"/>
        <source>Wi-Fi name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="85"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="86"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="87"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="88"/>
        <source>Connect</source>
        <translation type="unfinished">连接</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="90"/>
        <source>C_reate…</source>
        <translation type="unfinished">新建...</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="113"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../wireless-security/dlgconnhidwifiwpa.cpp" line="114"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key (Hex or ASCII)</source>
        <translation type="obsolete">WEP 40/128 位密钥(十六进制或ASCII)</translation>
    </message>
    <message>
        <source>WEP 128-bit Passphrase</source>
        <translation type="obsolete">WEP 128 位密码句</translation>
    </message>
    <message>
        <source>Dynamic WEP (802.1X)</source>
        <translation type="obsolete">动态 WEP (802.1x)</translation>
    </message>
    <message>
        <source>WPA &amp; WPA2 Enterprise</source>
        <translation type="obsolete">WPA 及 WPA2 企业</translation>
    </message>
</context>
<context>
    <name>DlgHotspotCreate</name>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="46"/>
        <source>Create Hotspot</source>
        <translation type="unfinished">创建个人热点</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="47"/>
        <source>Network name</source>
        <translation type="unfinished">网络名称:</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="48"/>
        <source>Wi-Fi security</source>
        <translation type="unfinished">Wi-Fi 安全性:</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="49"/>
        <source>Password</source>
        <translation type="unfinished">密码:</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="50"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="51"/>
        <source>Ok</source>
        <translation type="unfinished">确定</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="54"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../hot-spot/dlghotspotcreate.cpp" line="55"/>
        <source>WPA &amp; WPA2 Personal</source>
        <translation type="unfinished">WPA 及 WPA2 个人</translation>
    </message>
</context>
<context>
    <name>KylinDBus</name>
    <message>
        <source>kylin network applet desktop message</source>
        <translation type="obsolete">麒麟网络工具信息提示</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/mainwindow.cpp" line="532"/>
        <source>kylin-nm</source>
        <translation>网络工具</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="377"/>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <source>Advanced</source>
        <translation>设置网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="340"/>
        <location filename="../src/mainwindow.cpp" line="1180"/>
        <source>Ethernet</source>
        <translation>有线网络</translation>
    </message>
    <message>
        <source>Connect Hide Network</source>
        <translation type="vanished">加入网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="346"/>
        <location filename="../src/mainwindow.cpp" line="1239"/>
        <source>Wifi</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="vanished">已开启</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="vanished">已关闭</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="357"/>
        <source>HotSpot</source>
        <translation>个人热点</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="367"/>
        <source>FlyMode</source>
        <translation>飞行模式</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="536"/>
        <source>Show MainWindow</source>
        <translation>显示网络连接界面</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1143"/>
        <source>No wireless card detected</source>
        <translation type="unfinished">未检测到无线网卡</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1279"/>
        <location filename="../src/mainwindow.cpp" line="1356"/>
        <location filename="../src/mainwindow.cpp" line="1504"/>
        <location filename="../src/mainwindow.cpp" line="2200"/>
        <location filename="../src/mainwindow.cpp" line="2289"/>
        <source>Not connected</source>
        <translation>当前未连接任何网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1282"/>
        <location filename="../src/mainwindow.cpp" line="1358"/>
        <location filename="../src/mainwindow.cpp" line="1424"/>
        <location filename="../src/mainwindow.cpp" line="1425"/>
        <location filename="../src/mainwindow.cpp" line="1507"/>
        <location filename="../src/mainwindow.cpp" line="1586"/>
        <location filename="../src/mainwindow.cpp" line="1738"/>
        <location filename="../src/mainwindow.cpp" line="2202"/>
        <location filename="../src/mainwindow.cpp" line="2291"/>
        <source>Disconnected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1449"/>
        <source>No Other Wired Network Scheme</source>
        <translation type="unfinished">列表中无其他有线网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1608"/>
        <source>No Other Wireless Network Scheme</source>
        <translation type="unfinished">未检测到其他无线网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2111"/>
        <source>Wired net is disconnected</source>
        <translation type="unfinished">断开有线网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2139"/>
        <source>Wi-Fi is disconnected</source>
        <translation type="unfinished">断开无线网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2518"/>
        <source>Confirm your Wi-Fi password or usable of wireless card</source>
        <translation type="unfinished">请确认Wi-Fi密码或无线设备</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="225"/>
        <source>Ethernet Networks</source>
        <translation>可用有线网络列表</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="234"/>
        <source>New LAN</source>
        <translation type="unfinished">新建网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Hide WiFi</source>
        <translation>加入网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="287"/>
        <source>No usable network in the list</source>
        <translation type="unfinished">列表暂无可连接网络</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1403"/>
        <location filename="../src/mainwindow.cpp" line="1564"/>
        <source>NetOn,</source>
        <translation>已连接，</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="248"/>
        <source>Wifi Networks</source>
        <translation>可用无线网络列表</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">无</translation>
    </message>
    <message>
        <source>keep wired network switch is on before turning on wireless switch</source>
        <translation type="vanished">打开无线网开关前保持有线网开关打开</translation>
    </message>
    <message>
        <source>please insert the wireless network adapter</source>
        <translation type="vanished">请先插入无线网卡</translation>
    </message>
    <message>
        <source>Abnormal connection exist, program will delete it</source>
        <translation type="vanished">正在断开异常连接的网络</translation>
    </message>
    <message>
        <source>update Wi-Fi list now, click again</source>
        <translation type="vanished">正在更新 Wi-Fi列表 请再次点击</translation>
    </message>
    <message>
        <source>update Wi-Fi list now</source>
        <translation type="vanished">正在更新 Wi-Fi列表</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2474"/>
        <source>Conn Ethernet Success</source>
        <translation>连接有线网络成功</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2486"/>
        <source>Conn Ethernet Fail</source>
        <translation>连接有线网络失败</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2509"/>
        <source>Conn Wifi Success</source>
        <translation>连接无线网络成功</translation>
    </message>
</context>
<context>
    <name>NotifySend</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">--</translation>
    </message>
</context>
<context>
    <name>OneConnForm</name>
    <message>
        <location filename="../src/oneconnform.ui" line="14"/>
        <source>Form</source>
        <translation>--</translation>
    </message>
    <message>
        <source>Input password</source>
        <translation type="vanished">输入密码</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="42"/>
        <location filename="../src/oneconnform.cpp" line="43"/>
        <location filename="../src/oneconnform.cpp" line="44"/>
        <location filename="../src/oneconnform.cpp" line="46"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="45"/>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="47"/>
        <location filename="../src/oneconnform.cpp" line="285"/>
        <source>Input Password...</source>
        <translation type="unfinished">输入密码...</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="357"/>
        <source>Connect to Hidden Wi-Fi Network</source>
        <translation>连接到隐藏 Wi-Fi 网络</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="438"/>
        <source>Signal：</source>
        <translation type="unfinished">信号强度：</translation>
    </message>
    <message>
        <source>Public</source>
        <translation type="vanished">开放</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="368"/>
        <source>Rate</source>
        <translation>速率</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="435"/>
        <source>None</source>
        <translation type="unfinished">无</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="437"/>
        <source>WiFi Security：</source>
        <translation type="unfinished">WiFi安全性：</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="439"/>
        <source>MAC：</source>
        <translation type="unfinished">物理地址：</translation>
    </message>
    <message>
        <location filename="../src/oneconnform.cpp" line="689"/>
        <source>Conn Wifi Failed</source>
        <translation>连接无线网络失败</translation>
    </message>
</context>
<context>
    <name>OneLancForm</name>
    <message>
        <location filename="../src/onelancform.ui" line="14"/>
        <source>Form</source>
        <translation>--</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="31"/>
        <location filename="../src/onelancform.cpp" line="32"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="33"/>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="243"/>
        <location filename="../src/onelancform.cpp" line="247"/>
        <source>No Configuration</source>
        <translation type="unfinished">未配置</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="250"/>
        <source>IPv4：</source>
        <translation type="unfinished">IPv4地址：</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="251"/>
        <source>IPv6：</source>
        <translation type="unfinished">IPv6地址：</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="252"/>
        <source>BandWidth：</source>
        <translation type="unfinished">带宽：</translation>
    </message>
    <message>
        <location filename="../src/onelancform.cpp" line="253"/>
        <source>MAC：</source>
        <translation type="unfinished">物理地址：</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="obsolete">自动</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="87"/>
        <source>kylin network applet desktop message</source>
        <translation type="unfinished">麒麟网络工具信息提示</translation>
    </message>
</context>
</TS>
